==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkPlotBar.java <==
// java wrapper for vtkPlotBar object
//

package vtk;
import vtk.*;

public class vtkPlotBar extends vtkPlot
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native boolean Paint_3(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_3(id0); }

  private native void SetColor_4(char id0,char id1,char id2,char id3);
  public void SetColor(char id0,char id1,char id2,char id3)
    { SetColor_4(id0,id1,id2,id3); }

  private native void SetColor_5(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_5(id0,id1,id2); }

  private native void GetColor_6(double id0[]);
  public void GetColor(double id0[])
    { GetColor_6(id0); }

  private native void SetWidth_7(double id0);
  public void SetWidth(double id0)
    { SetWidth_7(id0); }

  private native double GetWidth_8();
  public double GetWidth()
    { return GetWidth_8(); }

  private native void SetOffset_9(double id0);
  public void SetOffset(double id0)
    { SetOffset_9(id0); }

  private native double GetOffset_10();
  public double GetOffset()
    { return GetOffset_10(); }

  private native void SetOrientation_11(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_11(id0); }

  private native int GetOrientation_12();
  public int GetOrientation()
    { return GetOrientation_12(); }

  private native void GetBounds_13(double id0[],boolean id1);
  public void GetBounds(double id0[],boolean id1)
    { GetBounds_13(id0,id1); }

  private native void GetBounds_14(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_14(id0); }

  private native void GetUnscaledInputBounds_15(double id0[]);
  public void GetUnscaledInputBounds(double id0[])
    { GetUnscaledInputBounds_15(id0); }

  private native void SetInputArray_16(int id0,String id1);
  public void SetInputArray(int id0,String id1)
    { SetInputArray_16(id0,id1); }

  private native void SetColorSeries_17(vtkColorSeries id0);
  public void SetColorSeries(vtkColorSeries id0)
    { SetColorSeries_17(id0); }

  private native long GetColorSeries_18();
  public vtkColorSeries GetColorSeries() {
    long temp = GetColorSeries_18();

    if (temp == 0) return null;
    return (vtkColorSeries)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLookupTable_19(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_19(id0); }

  private native long GetLookupTable_20();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_20();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CreateDefaultLookupTable_21();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_21(); }

  private native void SetScalarVisibility_22(boolean id0);
  public void SetScalarVisibility(boolean id0)
    { SetScalarVisibility_22(id0); }

  private native boolean GetScalarVisibility_23();
  public boolean GetScalarVisibility()
    { return GetScalarVisibility_23(); }

  private native void ScalarVisibilityOn_24();
  public void ScalarVisibilityOn()
    { ScalarVisibilityOn_24(); }

  private native void ScalarVisibilityOff_25();
  public void ScalarVisibilityOff()
    { ScalarVisibilityOff_25(); }

  private native void SelectColorArray_26(int id0);
  public void SelectColorArray(int id0)
    { SelectColorArray_26(id0); }

  private native void SelectColorArray_27(String id0);
  public void SelectColorArray(String id0)
    { SelectColorArray_27(id0); }

  private native String GetColorArrayName_28();
  public String GetColorArrayName()
    { return GetColorArrayName_28(); }

  private native long GetLabels_29();
  public vtkStringArray GetLabels() {
    long temp = GetLabels_29();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetGroupName_30(String id0);
  public void SetGroupName(String id0)
    { SetGroupName_30(id0); }

  private native String GetGroupName_31();
  public String GetGroupName()
    { return GetGroupName_31(); }

  private native int GetBarsCount_32();
  public int GetBarsCount()
    { return GetBarsCount_32(); }

  private native void GetDataBounds_33(double id0[]);
  public void GetDataBounds(double id0[])
    { GetDataBounds_33(id0); }

  public vtkPlotBar() { super(); }

  public vtkPlotBar(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-1-aarch64.pkg.tar.xz: vtk/vtkPlotBar.java <==
// java wrapper for vtkPlotBar object
//

package vtk;
import vtk.*;

public class vtkPlotBar extends vtkPlot
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Update_2();
  public void Update()
    { Update_2(); }

  private native boolean Paint_3(vtkContext2D id0);
  public boolean Paint(vtkContext2D id0)
    { return Paint_3(id0); }

  private native void SetColor_4(char id0,char id1,char id2,char id3);
  public void SetColor(char id0,char id1,char id2,char id3)
    { SetColor_4(id0,id1,id2,id3); }

  private native void SetColor_5(double id0,double id1,double id2);
  public void SetColor(double id0,double id1,double id2)
    { SetColor_5(id0,id1,id2); }

  private native void GetColor_6(double id0[]);
  public void GetColor(double id0[])
    { GetColor_6(id0); }

  private native void SetWidth_7(double id0);
  public void SetWidth(double id0)
    { SetWidth_7(id0); }

  private native double GetWidth_8();
  public double GetWidth()
    { return GetWidth_8(); }

  private native void SetOffset_9(double id0);
  public void SetOffset(double id0)
    { SetOffset_9(id0); }

  private native double GetOffset_10();
  public double GetOffset()
    { return GetOffset_10(); }

  private native void SetOrientation_11(int id0);
  public void SetOrientation(int id0)
    { SetOrientation_11(id0); }

  private native int GetOrientation_12();
  public int GetOrientation()
    { return GetOrientation_12(); }

  private native void GetBounds_13(double id0[],boolean id1);
  public void GetBounds(double id0[],boolean id1)
    { GetBounds_13(id0,id1); }

  private native void GetBounds_14(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_14(id0); }

  private native void GetUnscaledInputBounds_15(double id0[]);
  public void GetUnscaledInputBounds(double id0[])
    { GetUnscaledInputBounds_15(id0); }

  private native void SetInputArray_16(int id0,String id1);
  public void SetInputArray(int id0,String id1)
    { SetInputArray_16(id0,id1); }

  private native void SetColorSeries_17(vtkColorSeries id0);
  public void SetColorSeries(vtkColorSeries id0)
    { SetColorSeries_17(id0); }

  private native long GetColorSeries_18();
  public vtkColorSeries GetColorSeries() {
    long temp = GetColorSeries_18();

    if (temp == 0) return null;
    return (vtkColorSeries)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLookupTable_19(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_19(id0); }

  private native long GetLookupTable_20();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_20();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultLookupTable_21();
  public void CreateDefaultLookupTable()
    { CreateDefaultLookupTable_21(); }

  private native void SetScalarVisibility_22(boolean id0);
  public void SetScalarVisibility(boolean id0)
    { SetScalarVisibility_22(id0); }

  private native boolean GetScalarVisibility_23();
  public boolean GetScalarVisibility()
    { return GetScalarVisibility_23(); }

  private native void ScalarVisibilityOn_24();
  public void ScalarVisibilityOn()
    { ScalarVisibilityOn_24(); }

  private native void ScalarVisibilityOff_25();
  public void ScalarVisibilityOff()
    { ScalarVisibilityOff_25(); }

  private native void SelectColorArray_26(int id0);
  public void SelectColorArray(int id0)
    { SelectColorArray_26(id0); }

  private native void SelectColorArray_27(String id0);
  public void SelectColorArray(String id0)
    { SelectColorArray_27(id0); }

  private native String GetColorArrayName_28();
  public String GetColorArrayName()
    { return GetColorArrayName_28(); }

  private native long GetLabels_29();
  public vtkStringArray GetLabels() {
    long temp = GetLabels_29();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGroupName_30(String id0);
  public void SetGroupName(String id0)
    { SetGroupName_30(id0); }

  private native String GetGroupName_31();
  public String GetGroupName()
    { return GetGroupName_31(); }

  private native int GetBarsCount_32();
  public int GetBarsCount()
    { return GetBarsCount_32(); }

  private native void GetDataBounds_33(double id0[]);
  public void GetDataBounds(double id0[])
    { GetDataBounds_33(id0); }

  public vtkPlotBar() { super(); }

  public vtkPlotBar(long id) { super(id); }
  public native long   VTKInit();

}
